@@ -18,11 +18,11 @@ from celery import registry
 from celery.task.control import broadcast, revoke, rate_limit
 from celery.utils import abbrtask
 
-from djcelery import loaders
-from djcelery.admin_utils import action, display_field, fixedwidth
-from djcelery.models import TaskState, WorkerState
-from djcelery.models import PeriodicTask, IntervalSchedule, CrontabSchedule
-from djcelery.utils import naturaldate
+from . import loaders
+from .admin_utils import action, display_field, fixedwidth
+from .models import (TaskState, WorkerState,
+                     PeriodicTask, IntervalSchedule, CrontabSchedule)
+from .utils import naturaldate
 
 
 TASK_STATE_COLORS = {states.SUCCESS: "green",
@@ -49,7 +49,7 @@ def colored_state(task):
     return """<b><span style="color: %s;">%s</span></b>""" % (color, state)
 
 
-@display_field(_("state"), "last_timestamp")
+@display_field(_("state"), "last_heartbeat")
 def node_state(node):
     state = node.is_alive() and "ONLINE" or "OFFLINE"
     color = NODE_STATE_COLORS[state]
@@ -171,7 +171,6 @@ class TaskMonitor(ModelMonitor):
             "object_name": force_unicode(opts.verbose_name),
             "action_checkbox_name": helpers.ACTION_CHECKBOX_NAME,
             "opts": opts,
-            "root_path": self.admin_site.root_path,
             "app_label": app_label,
         }
 
