@@ -1,7 +1,9 @@
-from celery.app import default_app
+from __future__ import absolute_import
+
+from celery import current_app
 from celery.backends.base import BaseDictBackend
 
-from djcelery.models import TaskMeta, TaskSetMeta
+from ..models import TaskMeta, TaskSetMeta
 
 
 class DatabaseBackend(BaseDictBackend):
@@ -13,9 +15,11 @@ class DatabaseBackend(BaseDictBackend):
     TaskModel = TaskMeta
     TaskSetModel = TaskSetMeta
 
-    expires = default_app.conf.CELERY_TASK_RESULT_EXPIRES
+    expires = current_app.conf.CELERY_TASK_RESULT_EXPIRES
     create_django_tables = True
 
+    subpolling_interval = 0.5
+
     def _store_result(self, task_id, result, status, traceback=None):
         """Store return value and status of an executed task."""
         self.TaskModel._default_manager.store_result(task_id, result, status,
