@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+
 from collections import defaultdict
 from datetime import datetime, timedelta
 from time import time
@@ -11,11 +13,13 @@ from celery.events.state import Task
 from celery.events.snapshot import Polaroid
 from celery.utils.timeutils import maybe_iso8601
 
-from djcelery.models import WorkerState, TaskState
+from .models import WorkerState, TaskState
 
 
 WORKER_UPDATE_FREQ = 60  # limit worker timestamp write freq.
 SUCCESS_STATES = frozenset([states.SUCCESS])
+
+# Expiry can be timedelta or None for never expire.
 EXPIRE_SUCCESS = getattr(settings, "CELERYCAM_EXPIRE_SUCCESS",
                          timedelta(days=1))
 EXPIRE_ERROR = getattr(settings, "CELERYCAM_EXPIRE_ERROR",
