@@ -1,7 +1,9 @@
+from __future__ import absolute_import
+
 from datetime import datetime, timedelta
 
+from celery import current_app
 from celery import states
-from celery.app import default_app
 from celery.result import AsyncResult
 from celery.task import PeriodicTask
 from celery.utils import gen_unique_id
@@ -88,7 +90,7 @@ class TestDatabaseBackend(unittest.TestCase):
         self.assertEqual(b.TaskModel._default_manager.count(), 3)
 
         then = datetime.now() - \
-                default_app.conf.CELERY_TASK_RESULT_EXPIRES * 2
+                current_app.conf.CELERY_TASK_RESULT_EXPIRES * 2
         # Have to avoid save() because it applies the auto_now=True.
         b.TaskModel._default_manager.filter(task_id__in=ids[:-1]) \
                                     .update(date_done=then)
