@@ -1,7 +1,9 @@
+from __future__ import absolute_import
+
 from datetime import datetime, timedelta
 
+from celery import current_app
 from celery import states
-from celery.app import default_app
 from celery.utils import gen_unique_id
 
 from djcelery.models import TaskMeta, TaskSetMeta
@@ -44,13 +46,13 @@ class TestModels(unittest.TestCase):
                 date_done=datetime.now() - timedelta(days=10))
 
         expired = TaskMeta.objects.get_all_expired(
-                    default_app.conf.CELERY_TASK_RESULT_EXPIRES)
+                    current_app.conf.CELERY_TASK_RESULT_EXPIRES)
         self.assertIn(m1, expired)
         self.assertNotIn(m2, expired)
         self.assertNotIn(m3, expired)
 
         TaskMeta.objects.delete_expired(
-                    default_app.conf.CELERY_TASK_RESULT_EXPIRES)
+                    current_app.conf.CELERY_TASK_RESULT_EXPIRES)
         self.assertNotIn(m1, TaskMeta.objects.all())
 
     def test_tasksetmeta(self):
@@ -70,13 +72,13 @@ class TestModels(unittest.TestCase):
                 date_done=datetime.now() - timedelta(days=10))
 
         expired = TaskSetMeta.objects.get_all_expired(
-                    default_app.conf.CELERY_TASK_RESULT_EXPIRES)
+                    current_app.conf.CELERY_TASK_RESULT_EXPIRES)
         self.assertIn(m1, expired)
         self.assertNotIn(m2, expired)
         self.assertNotIn(m3, expired)
 
         TaskSetMeta.objects.delete_expired(
-                default_app.conf.CELERY_TASK_RESULT_EXPIRES)
+                current_app.conf.CELERY_TASK_RESULT_EXPIRES)
         self.assertNotIn(m1, TaskSetMeta.objects.all())
 
         m4 = self.createTaskSetMeta()
