@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+
 import sys
 
 from functools import partial
@@ -9,8 +11,8 @@ from django.template import TemplateDoesNotExist
 
 from anyjson import deserialize
 
+from celery import current_app
 from celery import states
-from celery.app import default_app
 from celery.datastructures import ExceptionInfo
 from celery.task import task
 from celery.utils import gen_unique_id, get_full_cls_name
@@ -58,7 +60,7 @@ def catch_exception(exception):
     try:
         raise exception
     except exception.__class__, exc:
-        exc = default_app.backend.prepare_exception(exc)
+        exc = current_app.backend.prepare_exception(exc)
         return exc, ExceptionInfo(sys.exc_info()).traceback
 
 
@@ -89,23 +91,23 @@ class ViewTestCase(DjangoTestCase):
 class test_task_apply(ViewTestCase):
 
     def test_apply(self):
-        default_app.conf.CELERY_ALWAYS_EAGER = True
+        current_app.conf.CELERY_ALWAYS_EAGER = True
         try:
             self.client.get(task_apply(kwargs={"task_name":
                 mytask.name}) + "?x=4&y=4")
             self.assertEqual(scratch["result"], 16)
         finally:
-            default_app.conf.CELERY_ALWAYS_EAGER = False
+            current_app.conf.CELERY_ALWAYS_EAGER = False
 
     def test_apply_raises_404_on_unregistered_task(self):
-        default_app.conf.CELERY_ALWAYS_EAGER = True
+        current_app.conf.CELERY_ALWAYS_EAGER = True
         try:
             name = "xxx.does.not.exist"
             action = partial(self.client.get, task_apply(kwargs={
                         "task_name": name}) + "?x=4&y=4")
             self.assertRaises(TemplateDoesNotExist, action)
         finally:
-            default_app.conf.CELERY_ALWAYS_EAGER = False
+            current_app.conf.CELERY_ALWAYS_EAGER = False
 
 
 class test_registered_tasks(ViewTestCase):
@@ -142,7 +144,7 @@ class test_webhook_task(ViewTestCase):
         request = MockRequest().get("/tasks/error", dict(x=10, y=10))
         response = error_webhook(request)
         self.assertDictContainsSubset({"status": "failure",
-                                       "reason": "20"},
+                                       "reason": "<MyError: (20,)>"},
                                       deserialize(response.content))
 
 
@@ -150,12 +152,12 @@ class test_task_status(ViewTestCase):
 
     def assertStatusForIs(self, status, res, traceback=None):
         uuid = gen_unique_id()
-        default_app.backend.store_result(uuid, res, status,
+        current_app.backend.store_result(uuid, res, status,
                                      traceback=traceback)
         json = self.client.get(task_status(task_id=uuid))
         expect = dict(id=uuid, status=status, result=res)
-        if status in default_app.backend.EXCEPTION_STATES:
-            instore = default_app.backend.get_result(uuid)
+        if status in current_app.backend.EXCEPTION_STATES:
+            instore = current_app.backend.get_result(uuid)
             self.assertEqual(str(instore.args[0]), str(res.args[0]))
             expect["result"] = repr(res)
             expect["exc"] = get_full_cls_name(res.__class__)
@@ -181,7 +183,7 @@ class test_task_is_successful(ViewTestCase):
     def assertStatusForIs(self, status, outcome):
         uuid = gen_unique_id()
         result = gen_unique_id()
-        default_app.backend.store_result(uuid, result, status)
+        current_app.backend.store_result(uuid, result, status)
         json = self.client.get(task_is_successful(task_id=uuid))
         self.assertJSONEqual(json, {"task": {"id": uuid,
                                              "executed": outcome}})
